@@ -1044,7 +1044,8 @@ input.freq.table = table.with.all.freqs[,1:mfw]
 
 supported.measures = c("dist.euclidean", "dist.manhattan", "dist.canberra",
                        "dist.delta", "dist.eder", "dist.argamon",
-                       "dist.simple", "dist.cosine")
+                       "dist.simple", "dist.cosine", "dist.wurzburg",
+                       "dist.entropy", "dist.minmax")
 
 
 
@@ -1079,11 +1080,16 @@ if(length(grep(distance.measure, supported.measures)) > 1 ) {
          # apply a standard distance, using the generic dist() function
          distance.table = as.matrix(dist(input.freq.table, method = distance))
     # then, check for the non-standard methods but still supported by Stylo
-    } else if(distance %in% c("dist.simple", "dist.cosine")) {
+    } else if(distance %in% c("dist.simple", "dist.cosine", "dist.entropy", "dist.minmax")) {
 
          # invoke one of the distance measures functions from Stylo    
-         distance.table = do.call(distance, list(x = input.freq.table))
-    
+         distance.table = do.call(distance, list(x = input.freq.table[,1:mfw]))
+
+    } else if(distance == "dist.wurzburg") {
+
+         # invoke one of the distance measures functions from Stylo    
+         distance.table = do.call(distance, list(x = table.with.all.zscores[,1:mfw]))
+            
     } else {
          # invoke one of the distances supported by 'stylo'; this is slightly
          # different from the custom functions invoked above, since it uses
